@@ -1,10 +1,10 @@
-# @(#)$Id: Util.pm 285 2011-07-11 12:40:49Z pjf $
+# @(#)$Id: Util.pm 321 2011-11-30 00:01:49Z pjf $
 
 package File::DataClass::Util;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.6.%d', q$Rev: 285 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 321 $ =~ /\d+/gmx );
 
 use Class::MOP;
 use File::DataClass::Constants;
@@ -14,7 +14,7 @@ use List::Util qw(first);
 use Moose::Role;
 use Try::Tiny;
 
-requires qw(Exception_Class);
+requires qw(exception_class);
 
 sub basename {
    my ($self, $path, @suffixes) = @_;
@@ -54,7 +54,7 @@ sub ensure_class_loaded {
 sub io {
    my ($self, @rest) = @_; my $io = File::DataClass::IO->new( @rest );
 
-   $io->exception_class( $self->Exception_Class );
+   $io->exception_class( $self->exception_class );
 
    return $io;
 }
@@ -66,7 +66,7 @@ sub is_member {
 }
 
 sub throw {
-   my $self = shift; return $self->Exception_Class->throw( @_ );
+   shift->exception_class->throw( @_ ); return;
 }
 
 no Moose::Role;
@@ -83,7 +83,7 @@ File::DataClass::Util - Moose Role defining utility methods
 
 =head1 Version
 
-0.6.$Revision: 285 $
+0.7.$Revision: 321 $
 
 =head1 Synopsis
 
